@@ -20,7 +20,9 @@ from kamocli.__main__ import app
 
 @app.command("login", help="Authenticate")
 def cli(ctx: Context):
-    raise NotImplementedError("This functionality is currently not implemented. Please use 'kamo auth' and enter API Key")
+    raise NotImplementedError(
+        "This functionality is currently not implemented. Please use 'kamo auth' and enter API Key"
+    )
     PORT = 9898
     redirect_uri = f"http://localhost:{PORT}"
 
@@ -75,9 +77,7 @@ def cli(ctx: Context):
                     headers=headers,
                 )
                 refresh_token = resp.json()["refresh_token"]
-                create_profile(
-                    get_default_profile(), api_key=refresh_token, domain=profile["domain"]
-                )
+                create_profile(get_default_profile(), api_key=refresh_token, domain=profile["domain"])
                 secho("You have been logged in", bold=True)
 
                 # shut down the webserver in another thread to avoid deadlock
